@@ -21,7 +21,7 @@ class AlprBase(Base):
         self.options = options
         self.disable_locks = options.get('disable_locks', 'no')
 
-        self.logger.Debug (4, 'ALPR init params: {}'.format(options))
+        #self.logger.Debug (4, 'ALPR init params: {}'.format(options))
 
     def acquire_lock(self):
         pass
